@@ -10,6 +10,7 @@ from dateutil import parser
 
 import requests
 from requests import Response
+from kameleoon.client_configuration import KameleoonClientConfiguration
 
 from kameleoon.data import Conversion, get_nonce, Data
 from kameleoon.defaults import DEFAULT_BLOCKING, DEFAULT_CONFIGURATION_PATH, DEFAULT_TIMEOUT_MILLISECONDS, \
@@ -58,10 +59,12 @@ class KameleoonClient:
     """
     initialize = False
 
+    # pylint: disable=R0913
     def __init__(
             self, site_code: str,
             blocking: bool = DEFAULT_BLOCKING,
             configuration_path: str = DEFAULT_CONFIGURATION_PATH,
+            configuration_object: Optional[KameleoonClientConfiguration] = None,
             logger=None
     ):
         """
@@ -76,6 +79,9 @@ class KameleoonClient:
         :param configuration_path: Path to the SDK configuration file.
                                    This field is optional and set to /etc/kameleoon/client-python.yaml by default.
         :type configuration_path: str
+        :param configuration:   Configuration object which can be used instead of external file at configuration_path.
+                                This field is optional set to None by default.
+        :type configuration: KameleoonClientConfiguration
         :param logger: Optional component which provides a log method to log messages. By default see method get_logger.
         """
         # pylint: disable=too-many-instance-attributes
@@ -84,23 +90,10 @@ class KameleoonClient:
         self.blocking = blocking
         self.experiments: List[Dict[str, Any]] = []
         self.feature_flags: List[Dict[str, str]] = []
-        config_yml = configuration_path or DEFAULT_CONFIGURATION_PATH
-        self.config = config(config_yml)
         self.logger = logger or get_logger()
         self.automation_base_url = "https://api.kameleoon.com/"
         self.api_data_url = "https://api-data.kameleoon.com/"
-        try:
-            target_environment = self.config['target_environment']
-        except KeyError:
-            target_environment = 'prod'
-        if target_environment == 'test':
-            self.tracking_base_url = "https://api-ssx.kameleoon.net/"
-        else:
-            self.tracking_base_url = "https://api-ssx.kameleoon.com/"
-        try:
-            self.environment = self.config['environment']
-        except KeyError:
-            self.environment = 'production'
+        self._setup_client_configuration(configuration_path, configuration_object)
         auth_resp = self._obtain_access_token()
         if auth_resp:
             self.access_token = auth_resp['access_token']
@@ -1210,3 +1203,24 @@ class KameleoonClient:
                 'Passing `feature_key` with type of `int` to `activate_feature` or `obtain_feature_variable` '
                 'is deprecated, it will be removed in next releases. This is necessary to support multi-environment '
                 'feature')
+
+    def _setup_client_configuration(self,
+                                    configuration_path: str,
+                                    configuration_object: Optional[KameleoonClientConfiguration]):
+        """
+        helper method to parse client configuration and setup client
+        """
+        config_yml = configuration_path or DEFAULT_CONFIGURATION_PATH
+        self.config = config(config_yml, configuration_object)
+        try:
+            target_environment = self.config['target_environment']
+        except KeyError:
+            target_environment = 'prod'
+        if target_environment == 'test':
+            self.tracking_base_url = "https://api-ssx.kameleoon.net/"
+        else:
+            self.tracking_base_url = "https://api-ssx.kameleoon.com/"
+        try:
+            self.environment = self.config['environment']
+        except KeyError:
+            self.environment = 'production'
